#!/bin/sh

# nvram-excp-codename.sh
# Adjust nvram parameters for code specific issues
# Supports OEM and Merlin firmware ONLY

# Changelog
#------------------------------------------------
# Version 15a			     6 March-2015
# add check for numeric extendno for ASUS OEM code
#
# Version 15			 25-February-2015
# - remove SNMP vars if not supported
# - update fork specific vars for removal
# - add version string for consistency check
#
# Version 14			  7-February-2015
# - update script name to include codename
# - update fork variables for delete
# - force jffs on for move to 378 code if off
#	if jffs already active, turn on scripts
# - use new vpn_server var for move to 378 code	
#
# Version 12                      1-February-2015			
# - use previous code in determining actions
#
# Version 11                      29-January-2015
# - Initial release into overall package
# - (378)  single maclist for filtering
# - (^378) delete Merlin specific variables
# - (^374) delete fork specific variables
#
#------------------------------------------------
#version=15a

# Get current code level
buildno=$(nvram get buildno)
major=$(echo "$buildno" | awk -F"." '{ print $1; }')
minor=$(echo "$buildno" | awk -F"." '{ print $2; }')
if [ "$minor" == "" ]; then
	minor=0
fi

# Get previous code level
buildno_org=$(nvram get buildno_org)
major_org=$(echo "$buildno_org" | awk -F"." '{ print $1; }')
minor_org=$(echo "$buildno_org" | awk -F"." '{ print $2; }')
if [ "$minor_org" == "" ]; then
	minor_org=0
fi

# Check for numeric extendno (ASUS release)
asusno=$(nvram get extendno)
if ! [[ "$asusno" -eq "$asusno" ]] 2>/dev/null; then 
	asusno=0
fi

# Update nvram based on code level specifics
if [[ $major -ge 378 && $major_org -lt 378 ]]; then
		# No longer separate maclist filters per radio
		wla_maclist_x=$(nvram get wl0_maclist_x | sed 's/</\n/g' | grep ":" | awk -F">" '{ print $1">"$2; }')
		wla_maclist_x=$wla_maclist_x"\n"$(nvram get wl1_maclist_x | sed 's/</\n/g' | grep ":" | awk -F">" '{ print $1">"$2; }')
		wla_maclist_x=$(echo -e "$wla_maclist_x" | sort -u | awk -F">" '{ print $1">"$2; }')
		wla_maclist_x=$(echo -e "$wla_maclist_x" | sed 's/^/</g' | tr -d '\n' )

		$(nvram set wl0_maclist_x="$wla_maclist_x")
		$(nvram set wl1_maclist_x="$wla_maclist_x")

		# Force jffs on
		if [ $(nvram get jffs2_on) == "0" ]; then
			nvram set jffs2_on="1"
			nvram set jffs2_format="1"
			nvram set jffs2_scripts="0"
		else
			# jffs already on, enable scripts
			nvram set jffs2_scripts="1"
		fi
		
		# New vpn server var
		nvram set vpn_serverx_start="$(nvram get vpn_serverx_eas)"
fi

if [[ $major -lt 378 ]]; then
		# Delete 378 unique vars
		nvram unset vpn_serverx_start
		nvram unset jffs2_scripts
fi

if [[ $major -lt 376 ]] || [[ $minor -lt 47 && $minor -gt 0 ]] || [[ $major -eq 376 && $minor -eq 0 && $asusno -lt 2678 ]]; then
		# Delete SNMP support vars
		nvram unset snmpd_enable
		nvram unset snmpd_wan
		nvram unset sysName
		nvram unset sysContact
		nvram unset sysLocation
		nvram unset roCommunity
		nvram unset rwCommunity
		nvram unset v3_auth_type
		nvram unset v3_priv_type
		nvram unset v3_auth_passwd
		nvram unset v3_priv_passwd
fi

if [[ $major -ne 374 || $minor -ne 43 ]]; then
		# Delete Merlin/Fork specific parameters
		nvram unset jffs2_log
		nvram unset DSCP_fix_enable
		nvram unset rstats_units
		nvram unset sshd_addr
		nvram unset log_small
fi

exit 0